@@ -16,6 +16,8 @@
 
 from django_tables2.config import RequestConfig
 
+from django_tables2_reports.utils import REQUEST_VARIABLE
+
 
 class RequestConfigReport(RequestConfig):
 
@@ -28,8 +30,11 @@ class RequestConfigReport(RequestConfig):
         table.is_configured = True
         param_report = table.param_report
         is_report = self.request.GET.get(param_report)
+        table_to_csv = None
         if is_report:
             self.paginate = self.paginate_report
-            self.request.table = table
+            table_to_csv = table
+            setattr(self.request, REQUEST_VARIABLE, table_to_csv)
             self.request.extra_context = extra_context or {}
         super(RequestConfigReport, self).configure(table)
+        return table_to_csv
