@@ -14,8 +14,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this software.  If not, see <http://www.gnu.org/licenses/>.
 
+from django.http import HttpResponse
+
 
 DEFAULT_PARAM_PREFIX = 'report'
+REQUEST_VARIABLE = 'table_to_csv'
+REPORT_MYMETYPE = 'application/vnd.ms-excel'
 
 
 def generate_prefixto_report(table, prefix_param_report=None):
@@ -25,3 +29,13 @@ def generate_prefixto_report(table, prefix_param_report=None):
     if prefix:
         param_report = "%s-%s" % (prefix, param_report)
     return param_report
+
+
+def create_report_http_response(table, request):
+    format = request.GET.get(table.param_report)
+    report = table.as_report(request, format=format)
+    filename = '%s.%s' % (table.param_report, format)
+    response = HttpResponse(report, mimetype=REPORT_MYMETYPE)
+    response['Content-Disposition'] = 'attachment; filename=%s' % filename
+    response = table.treatement_to_response(response, format=format)
+    return response
